pub struct MetricEventLoggerLogIntegerRequest {
pub metric_id: u32,
pub value: i64,
pub event_codes: Vec<u32>,
}Fields
metric_id: u32value: i64event_codes: Vec<u32>Trait Implementations
Sourceimpl Clone for MetricEventLoggerLogIntegerRequest
impl Clone for MetricEventLoggerLogIntegerRequest
Sourcefn clone(&self) -> MetricEventLoggerLogIntegerRequest
fn clone(&self) -> MetricEventLoggerLogIntegerRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'a, ___E> Encode<MetricEventLoggerLogIntegerRequest<'static>, ___E> for &'a MetricEventLoggerLogIntegerRequestwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<MetricEventLoggerLogIntegerRequest<'static>, ___E> for &'a MetricEventLoggerLogIntegerRequestwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<MetricEventLoggerLogIntegerRequest<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<MetricEventLoggerLogIntegerRequest<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<MetricEventLoggerLogIntegerRequest<'static>, ___E> for MetricEventLoggerLogIntegerRequestwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<MetricEventLoggerLogIntegerRequest<'static>, ___E> for MetricEventLoggerLogIntegerRequestwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<MetricEventLoggerLogIntegerRequest<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<MetricEventLoggerLogIntegerRequest<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, MetricEventLoggerLogIntegerRequest<'static>>, ___E> for &'a MetricEventLoggerLogIntegerRequestwhere
___E: Encoder + ?Sized,
&'a MetricEventLoggerLogIntegerRequest: Encode<MetricEventLoggerLogIntegerRequest<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, MetricEventLoggerLogIntegerRequest<'static>>, ___E> for &'a MetricEventLoggerLogIntegerRequestwhere
___E: Encoder + ?Sized,
&'a MetricEventLoggerLogIntegerRequest: Encode<MetricEventLoggerLogIntegerRequest<'static>, ___E>,
Sourcefn encode_option(
this: Option<&'a MetricEventLoggerLogIntegerRequest>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, MetricEventLoggerLogIntegerRequest<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a MetricEventLoggerLogIntegerRequest>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, MetricEventLoggerLogIntegerRequest<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, MetricEventLoggerLogIntegerRequest<'static>>, ___E> for MetricEventLoggerLogIntegerRequestwhere
___E: Encoder + ?Sized,
MetricEventLoggerLogIntegerRequest: Encode<MetricEventLoggerLogIntegerRequest<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, MetricEventLoggerLogIntegerRequest<'static>>, ___E> for MetricEventLoggerLogIntegerRequestwhere
___E: Encoder + ?Sized,
MetricEventLoggerLogIntegerRequest: Encode<MetricEventLoggerLogIntegerRequest<'static>, ___E>,
Sourcefn encode_option(
this: Option<MetricEventLoggerLogIntegerRequest>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, MetricEventLoggerLogIntegerRequest<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<MetricEventLoggerLogIntegerRequest>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, MetricEventLoggerLogIntegerRequest<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<MetricEventLoggerLogIntegerRequest<'de>> for MetricEventLoggerLogIntegerRequest
impl<'de> FromWire<MetricEventLoggerLogIntegerRequest<'de>> for MetricEventLoggerLogIntegerRequest
Sourcefn from_wire(
wire: MetricEventLoggerLogIntegerRequest<'de>,
) -> MetricEventLoggerLogIntegerRequest
fn from_wire( wire: MetricEventLoggerLogIntegerRequest<'de>, ) -> MetricEventLoggerLogIntegerRequest
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<MetricEventLoggerLogIntegerRequest<'de>> for MetricEventLoggerLogIntegerRequest
impl<'de> FromWireRef<MetricEventLoggerLogIntegerRequest<'de>> for MetricEventLoggerLogIntegerRequest
Sourcefn from_wire_ref(
wire: &MetricEventLoggerLogIntegerRequest<'de>,
) -> MetricEventLoggerLogIntegerRequest
fn from_wire_ref( wire: &MetricEventLoggerLogIntegerRequest<'de>, ) -> MetricEventLoggerLogIntegerRequest
Converts the given reference to this type.
Sourceimpl Ord for MetricEventLoggerLogIntegerRequest
impl Ord for MetricEventLoggerLogIntegerRequest
Sourcefn cmp(&self, other: &MetricEventLoggerLogIntegerRequest) -> Ordering
fn cmp(&self, other: &MetricEventLoggerLogIntegerRequest) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for MetricEventLoggerLogIntegerRequest
impl PartialEq for MetricEventLoggerLogIntegerRequest
Sourcefn eq(&self, other: &MetricEventLoggerLogIntegerRequest) -> bool
fn eq(&self, other: &MetricEventLoggerLogIntegerRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for MetricEventLoggerLogIntegerRequest
impl PartialOrd for MetricEventLoggerLogIntegerRequest
impl Eq for MetricEventLoggerLogIntegerRequest
impl StructuralPartialEq for MetricEventLoggerLogIntegerRequest