#[repr(C)]pub struct HistogramBucket {
pub index: Uint32,
pub count: Uint64,
}Expand description
The wire type corresponding to HistogramBucket.
Fields
index: Uint32count: Uint64Trait Implementations
Sourceimpl Clone for HistogramBucket
impl Clone for HistogramBucket
Sourcefn clone(&self) -> HistogramBucket
fn clone(&self) -> HistogramBucket
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for HistogramBucket
impl Constrained for HistogramBucket
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, HistogramBucket>,
_: <HistogramBucket as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, HistogramBucket>, _: <HistogramBucket as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for HistogramBucket
impl Debug for HistogramBucket
Sourceimpl<___D> Decode<___D> for HistogramBucketwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for HistogramBucketwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<HistogramBucket, ___E> for &'a HistogramBucketwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<HistogramBucket, ___E> for &'a HistogramBucketwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<HistogramBucket>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<HistogramBucket>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<HistogramBucket, ___E> for HistogramBucketwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<HistogramBucket, ___E> for HistogramBucketwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<HistogramBucket>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<HistogramBucket>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0, T1> Encode<HistogramBucket, ___E> for HistogramBucket<T0, T1>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
T1: Encode<Uint64, ___E>,
impl<___E, T0, T1> Encode<HistogramBucket, ___E> for HistogramBucket<T0, T1>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
T1: Encode<Uint64, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<HistogramBucket>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<HistogramBucket>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<HistogramBucket> for HistogramBucket
impl FromWire<HistogramBucket> for HistogramBucket
Sourcefn from_wire(wire: HistogramBucket) -> HistogramBucket
fn from_wire(wire: HistogramBucket) -> HistogramBucket
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<HistogramBucket> for HistogramBucket
impl FromWireRef<HistogramBucket> for HistogramBucket
Sourcefn from_wire_ref(wire: &HistogramBucket) -> HistogramBucket
fn from_wire_ref(wire: &HistogramBucket) -> HistogramBucket
Converts the given reference to this type.
Sourceimpl IntoNatural for HistogramBucket
impl IntoNatural for HistogramBucket
Sourcetype Natural = HistogramBucket
type Natural = HistogramBucket
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for HistogramBucket
impl Wire for HistogramBucket
Sourcetype Narrowed<'de> = HistogramBucket
type Narrowed<'de> = HistogramBucket
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<HistogramBucket>)
fn zero_padding(out_: &mut MaybeUninit<HistogramBucket>)
Writes zeroes to the padding for this type, if any.